<?php

class SmsSender
{
    private static $apiUrl = 'https://my.kudisms.net/api/sms';

    private $key;
    public function __construct()
    {
        $this->key =  getenv('KUDI_SECRET');
    }

    /**
     * Sends an SMS using the specified parameters.
     *
     * @param string $token API token for authentication.
     * @param string $senderID The sender ID for the SMS.
     * @param string $recipients Comma-separated list of recipient phone numbers.
     * @param string $message The SMS message to be sent.
     * @param int $gateway The gateway to be used (default: 2).
     * @return string|false The response from the API, or false on failure.
     */
    public function sendSms($phone, $message)
    {

        $params = [
            'token' => $this->key,
            'senderID' => "SAMOGOZA",
            'recipients' => $phone,
            'message' => $message,
            'gateway' => 2
        ];

        $url = self::$apiUrl . '?' . http_build_query($params);

        $curlHandle = curl_init();

        curl_setopt($curlHandle, CURLOPT_URL, $url);
        curl_setopt($curlHandle, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curlHandle, CURLOPT_CUSTOMREQUEST, 'GET');

        $response = curl_exec($curlHandle);

        if (curl_errno($curlHandle)) {
            echo 'Error: ' . curl_error($curlHandle);
            curl_close($curlHandle);
            return false;
        }

        curl_close($curlHandle);
        return $response;
    }


    /**
     * Sends an OTP via the Kudisms API.
     *
     * @param string $token API token for authentication.
     * @param string $senderID The sender ID for the OTP.
     * @param string $recipients Comma-separated list of recipient phone numbers.
     * @param string $otp The OTP to be sent.
     * @param string $appnamecode App name code for the API.
     * @param string $templatecode Template code for the OTP.
     * @return string|false The response from the API, or false on failure.
     */
    function sendOtp($recipients, $otp)
    {
        $url = 'https://my.kudisms.net/api/otp';
        $postData = json_encode([
            'token' => $this->key,
            'senderID' => "SAMOGOZA",
            'recipients' => $recipients,
            'otp' => $otp,
            'appnamecode' => '3124244314',
            'templatecode' => '7366476673',
        ]); 
        
        $curlHandle = curl_init();

        curl_setopt($curlHandle, CURLOPT_URL, $url);
        curl_setopt($curlHandle, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curlHandle, CURLOPT_POST, true);
        curl_setopt($curlHandle, CURLOPT_POSTFIELDS, $postData);

        $headers = [
            'Content-Type: application/json',
        ];
        curl_setopt($curlHandle, CURLOPT_HTTPHEADER, $headers);

        $response = curl_exec($curlHandle);

        if (curl_errno($curlHandle)) {
            echo 'Error: ' . curl_error($curlHandle);
            curl_close($curlHandle);
            return false;
        }

        curl_close($curlHandle);
        return $response;
    }
}

// // Usage
// $response = SmsSender::sendSms(
//     'BZtVPJU1frA6i8sbyScXx3LqHD92OkwRljaNQ0WFg7ue5Md4GTKoEhzpYnmCvI', // token
//     'neo', // senderID
//     '2349036425748,2348153197053', // recipients
//     'helloath', // message
//     2 // gateway
// );

// if ($response !== false) {
//     echo 'Response: ' . $response;
// }
