<?php
class CommonFunctions
{
    
    // Function to sanitize user input to prevent SQL injection
    public static function clean($value)
    {
        $value = trim($value);
        $value = htmlspecialchars($value, ENT_QUOTES, 'UTF-8');
        $value = strip_tags($value);
        return $value;
    }

    //* Function to generate a unique identifier
    public static function generateUniqueID()
    {
        return md5(bin2hex(random_bytes(43)) . date("YmdHis"));
    }

    public static function getDateTime($hours=1)
    {
        $futureTime = strtotime("+$hours hours");
        return gmdate("Y-m-d H:i:s", $futureTime);
    }

    public static function getExpDate($duration)
    {
        $futureTime = strtotime("+$duration ");
        return gmdate("Y-m-d H:i:s", $futureTime);
    }

    //*format dollar amount
    public static function formatDollar($data)
    {
        return "$" . number_format($data, 2);
    }

    //*format Naira amount
    public static function formatNaira($data)
    {
        return "&#8358;" . number_format($data, 2);
    }
    public static function formatNairaWithout($data)
    {
        return number_format($data, 2);
    }

    public static function formatDate($data)
    {
        return date("d M, Y", strtotime($data));
    }

    public static function generateLink($text)
    {
        $cleanedText = preg_replace('/[^\p{L}\d]+/u', '-', $text);
        $cleanedText = trim($cleanedText, '-');
        $cleanedText = preg_replace('/-+/', '-', $cleanedText);
        $cleanedText = strtolower($cleanedText);
        return $cleanedText;
    }

    public static function showAlert($message, $type = 'success')
    {
        $alertClass = $type === 'success' ? 'alert-success' : 'alert-danger';
        $iconClass = $type === 'success' ? 'fa-check-circle' : 'fa-exclamation-circle';

        $alert = '<div class="alert ' . $alertClass . ' alert-dismissible fade show" role="alert">
                    <i class="fa ' . $iconClass . '"></i> ' . $message . '
                    
                </div>';

        return $alert;
    }

    public static function sweetAlert($message, $type = 'info')
    { 
        $_SESSION['msg'] = $message;
        $_SESSION['type'] = $type=='info' ? 'info' : 'error';
         
    }



    public  function removeUnnecessaryCommas($text)
    {
        // Use a regular expression to match commas not followed by a word character
        $cleanedText = preg_replace('/,(?!\w)/', '', $text);
        return $cleanedText;
    }


    public static function route($route)
    {
        return header("Location: " . $route);
    }

    public static function generateOrderID()
    {
        // Use current timestamp
        $timestamp = time();

        // Generate a random number
        $randomNumber = mt_rand(1000, 9999);

        // Concatenate timestamp and random number to create a unique ID
        $orderID = 'ORD' . $timestamp . $randomNumber;

        return $orderID;
    }


    public static function limitText($text, $limit)
    {
        if (strlen($text) > $limit) {
            $text = substr($text, 0, $limit) . '...';
        }
        return $text;
    }

    public static function sendMail($mailTemplate, $email, $subject)
    {
        $test = __DIR__ . "/emailController/mailTemplate.php";
        require __DIR__ . "/emailController/mailTemplateApi.php";
    }

    public static function sendNumber($number) {
        
        $number = strval($number);
    
        if ($number[0] === '0') {
            $number = substr($number, 1);
        }

        if (substr($number, 0, 3) !== '234') {
            $number = '234' . $number;
        }
    
        return $number;
    }
    
  
}


 