<?php

class Helper
{
    private $pdo;
    private $unique;
    private $query;
    public function __construct(PDO $pdo)
    {
        $this->pdo = $pdo;
        $this->unique = CommonFunctions::generateUniqueID();
    }



    public function getUser($userid, $column = "*")
    {
        $query = "SELECT $column FROM `dlogin` WHERE userid = :userid";
        $stmt = $this->pdo->prepare($query);
        $stmt->bindParam(':userid', $userid);
        $stmt->execute();

        return $stmt->fetch(PDO::FETCH_ASSOC);
    }


    function getKey($table, $column)
    {
        $stmt = $this->pdo->prepare("SELECT $column FROM $table");
        $stmt->execute();
        $data = $stmt->fetch(PDO::FETCH_ASSOC);
        return $data[$column];
    }

    //get All Record
    public function getAllRecord($tableName, $clause = '')
    {
        $query = "SELECT * FROM $tableName";
        if (!empty($clause)) {
            $query .= " $clause";
        }
        $stmt = $this->pdo->prepare($query);
        $stmt->execute();
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    public function getAllRecordWithSelector($tableName, $selector = "*", $clause = '')
    {
        $query = "SELECT $selector FROM $tableName";
        if (!empty($clause)) {
            $query .= " $clause";
        }
        $stmt = $this->pdo->prepare($query);
        $stmt->execute();
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }




    //get single record from database
    public function getSingleRecord($tableName, $clause = '')
    {
        $query = "SELECT * FROM $tableName";
        if (!empty($clause)) {
            $query .= " $clause";
        }
        $stmt = $this->pdo->prepare($query);
        $stmt->execute();
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }

    public function getTotalRowCount($tableName, $clause = '')
    {
        $query = "SELECT COUNT(*) AS total FROM $tableName";
        if (!empty($clause)) {
            $query .= " $clause";
        }
        $stmt = $this->pdo->prepare($query);
        $stmt->execute();
        $result = $stmt->fetch(PDO::FETCH_ASSOC);
        return $result['total'];
    }

    public function getTotalRowCountWithSelector($tableName, $selector = "*", $clause = '')
    {
        // Construct the query
        $query = "SELECT COUNT(*) AS total FROM (SELECT $selector FROM $tableName $clause) AS subquery";

        // Prepare and execute the query
        $stmt = $this->pdo->prepare($query);
        $stmt->execute();

        // Fetch and return the total count
        $result = $stmt->fetch(PDO::FETCH_ASSOC);
        return $result['total'];
    }



    public function getSingleRecordWithSelector($tableName,  $selector = "*", $clause = '')
    {
        $query = "SELECT $selector FROM $tableName";
        if (!empty($clause)) {
            $query .= " $clause";
        }
        $stmt = $this->pdo->prepare($query);
        $stmt->execute();
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }




    //TODO create new record
    public function create(string $table, array $values)
    {
        // Prepare the query dynamically
        $columns = implode(', ', array_keys($values));
        $setClause = implode(', ', array_map(fn($col) => "$col = :$col", array_keys($values)));

        $sql = "INSERT INTO $table SET $setClause";

        try {
            $stmt = $this->pdo->prepare($sql);
            $stmt->execute($values);
            return true;
        } catch (PDOException $e) {
            return false;
        }
    }

    //TODO update any table
    public function update(string $table, array $values, array $clause)
    {
        $setClause = implode(', ', array_map(fn($col) => "$col = :$col", array_keys($values)));
        $whereClause = implode(' AND ', array_map(fn($column) => "$column = :$column", array_keys($clause)));
        $sql = "UPDATE $table SET $setClause WHERE $whereClause";
        try {
            $stmt = $this->pdo->prepare($sql);
            foreach ($values as $key => $value) {
                $stmt->bindValue(":$key", $value);
            }
            foreach ($clause as $key => $value) {
                $stmt->bindValue(":$key", $value);
            }

            $stmt->execute();

            return true;
        } catch (PDOException $e) {
            // Handle exceptions
            return false;
        }
    }


    //TODO delete from any table
    public function remove(string $table, array $clause)
    {

        // Prepare the query dynamically
        $whereClause = '';
        foreach ($clause as $column => $condition) {
            $whereClause .= "$column = :$column AND ";
        }
        $whereClause = rtrim($whereClause, ' AND ');

        $sql = "DELETE FROM $table WHERE $whereClause";

        try {
            $stmt = $this->pdo->prepare($sql);
            $stmt->execute($clause);
            return true;
        } catch (PDOException $e) {
            return false;
        }
    }

  
}
